CustomerManagedEncryption

Struct CustomerManagedEncryption 

#[non_exhaustive]
pub struct CustomerManagedEncryption { pub kms_key_name: String, /* private fields */ }
Configuration for encrypting secret payloads using customer-managed encryption keys (CMEK).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
kms_key_name: String

Required. The resource name of the Cloud KMS CryptoKey used to encrypt secret payloads.

For secrets using the UserManaged replication policy type, Cloud KMS CryptoKeys must reside in the same location as the [replica location][Secret.UserManaged.Replica.location].

For secrets using the Automatic replication policy type, Cloud KMS CryptoKeys must reside in global.

The expected format is projects/*/locations/*/keyRings/*/cryptoKeys/*.

Implementations

Source

impl CustomerManagedEncryption

pub fn new() -> Self

pub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self

Sets the value of kms_key_name.

Example
let x = CustomerManagedEncryption::new().set_kms_key_name("example");