Replication

Struct Replication 

#[non_exhaustive]
pub struct Replication { pub replication: Option<Replication>, /* private fields */ }
A policy that defines the replication and encryption configuration of data.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
replication: Option<Replication>

The replication policy for this secret.

Implementations

Source

impl Replication

pub fn new() -> Self

pub fn set_replication<T: Into<Option<Replication>>>(self, v: T) -> Self

Sets the value of replication.

Note that all the setters affecting replication are mutually exclusive.

Example
use google_cloud_secretmanager_v1::model::replication::Automatic;
let x = Replication::new().set_replication(Some(
    google_cloud_secretmanager_v1::model::replication::Replication::Automatic(Automatic::default().into())));
pub fn automatic(&self) -> Option<&Box<Automatic>>

The value of replication if it holds a Automatic, None if the field is not set or holds a different branch.

pub fn set_automatic<T: Into<Box<Automatic>>>(self, v: T) -> Self

Sets the value of replication to hold a Automatic.

Note that all the setters affecting replication are mutually exclusive.

Example
use google_cloud_secretmanager_v1::model::replication::Automatic;
let x = Replication::new().set_automatic(Automatic::default()/* use setters */);
assert!(x.automatic().is_some());
assert!(x.user_managed().is_none());
pub fn user_managed(&self) -> Option<&Box<UserManaged>>

The value of replication if it holds a UserManaged, None if the field is not set or holds a different branch.

pub fn set_user_managed<T: Into<Box<UserManaged>>>(self, v: T) -> Self

Sets the value of replication to hold a UserManaged.

Note that all the setters affecting replication are mutually exclusive.

Example
use google_cloud_secretmanager_v1::model::replication::UserManaged;
let x = Replication::new().set_user_managed(UserManaged::default()/* use setters */);
assert!(x.user_managed().is_some());
assert!(x.automatic().is_none());