#[non_exhaustive]pub struct ReplicationStatus {
pub replication_status: Option<ReplicationStatus>,
/* private fields */
}Expand description
The replication status of a SecretVersion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.replication_status: Option<ReplicationStatus>The replication status of the SecretVersion.
Implementations
Sourceimpl ReplicationStatus
impl ReplicationStatus
pub fn new() -> Self
Sourcepub fn set_replication_status<T: Into<Option<ReplicationStatus>>>(
self,
v: T,
) -> Self
pub fn set_replication_status<T: Into<Option<ReplicationStatus>>>( self, v: T, ) -> Self
Sets the value of replication_status.
Note that all the setters affecting replication_status are mutually
exclusive.
Example
ⓘ
use google_cloud_secretmanager_v1::model::replication_status::AutomaticStatus;
let x = ReplicationStatus::new().set_replication_status(Some(
google_cloud_secretmanager_v1::model::replication_status::ReplicationStatus::Automatic(AutomaticStatus::default().into())));Sourcepub fn automatic(&self) -> Option<&Box<AutomaticStatus>>
pub fn automatic(&self) -> Option<&Box<AutomaticStatus>>
The value of replication_status
if it holds a Automatic, None if the field is not set or
holds a different branch.
Sourcepub fn set_automatic<T: Into<Box<AutomaticStatus>>>(self, v: T) -> Self
pub fn set_automatic<T: Into<Box<AutomaticStatus>>>(self, v: T) -> Self
Sets the value of replication_status
to hold a Automatic.
Note that all the setters affecting replication_status are
mutually exclusive.
Example
ⓘ
use google_cloud_secretmanager_v1::model::replication_status::AutomaticStatus;
let x = ReplicationStatus::new().set_automatic(AutomaticStatus::default()/* use setters */);
assert!(x.automatic().is_some());
assert!(x.user_managed().is_none());Sourcepub fn user_managed(&self) -> Option<&Box<UserManagedStatus>>
pub fn user_managed(&self) -> Option<&Box<UserManagedStatus>>
The value of replication_status
if it holds a UserManaged, None if the field is not set or
holds a different branch.
Sourcepub fn set_user_managed<T: Into<Box<UserManagedStatus>>>(self, v: T) -> Self
pub fn set_user_managed<T: Into<Box<UserManagedStatus>>>(self, v: T) -> Self
Sets the value of replication_status
to hold a UserManaged.
Note that all the setters affecting replication_status are
mutually exclusive.
Example
ⓘ
use google_cloud_secretmanager_v1::model::replication_status::UserManagedStatus;
let x = ReplicationStatus::new().set_user_managed(UserManagedStatus::default()/* use setters */);
assert!(x.user_managed().is_some());
assert!(x.automatic().is_none());Trait Implementations
Sourceimpl Clone for ReplicationStatus
impl Clone for ReplicationStatus
Sourcefn clone(&self) -> ReplicationStatus
fn clone(&self) -> ReplicationStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplicationStatus
impl Debug for ReplicationStatus
Sourceimpl Default for ReplicationStatus
impl Default for ReplicationStatus
Sourcefn default() -> ReplicationStatus
fn default() -> ReplicationStatus
Returns the “default value” for a type. Read more
Sourceimpl Message for ReplicationStatus
impl Message for ReplicationStatus
Sourceimpl PartialEq for ReplicationStatus
impl PartialEq for ReplicationStatus
impl StructuralPartialEq for ReplicationStatus