#[non_exhaustive]pub struct Topic {
pub name: String,
/* private fields */
}Expand description
A Pub/Sub topic which Secret Manager will publish to when control plane events occur on this secret.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the Pub/Sub topic that will be published
to, in the following format: projects/*/topics/*. For publication to
succeed, the Secret Manager service agent must have the
pubsub.topic.publish permission on the topic. The Pub/Sub Publisher role
(roles/pubsub.publisher) includes this permission.
Implementations